@@ -189,7 +189,7 @@ class StickPoint:
             outname = self._base_path + 'data/img/' + new_name + '_stick_point.png'
             
             
-        pl.start_xvfb()
+        pv.start_xvfb()
         # pl.show(screenshot=outname, jupyter_backend='panel')
         pl.show(screenshot=outname, title=title)
 
