@@ -364,11 +364,12 @@ class DataHandler:
         """
         fname = self._out_path + ".mol2"
 
-        # Check if mol2 file exists. If not convert it from pdb
-        file_exists = exists(fname)
-        fc = FileConverter()
-        if not file_exists:
-            fc.pdb_to_mol2(self._path)
+        # # Check if mol2 file exists. If not convert it from pdb
+        # file_exists = exists(fname)
+        # fc = FileConverter()
+        # fc.pdb_to_mol2(self._path, self._out_path)
+        # if not file_exists:
+        #     fc.pdb_to_mol2(self._path, self._out_path)
         pmol = PandasMol2().read_mol2(fname)
         bonds_in = bond_parser(fname)
 
